@@ -1,8 +1,6 @@
 package WebService::Steam::Group;
 
-use IO::All;
 use Moose;
-use MooseX::MarkAsMethods autoclean => 1;
 
 use overload '""' => sub { $_[0]->name };
 
@@ -14,8 +12,6 @@ sub path { "http://steamcommunity.com/@{[ $_[1] =~ /^\d+$/ ? 'gid' : 'groups' ]}
 __PACKAGE__->meta->make_immutable;
 
 1;
-
-__END__
  
 =head1 NAME
 
